var isEditing = false;
var selectedRow = 0;

var typeSelector = 'select[id^="ssm_extensions["][id$="][type]"]';
var didSelector = 'select[id^="ssm_extensions["][id$="][did]"]';
var phoneSelector = 'select[id^="ssm_extensions["][id$="][phone]"]';

var ssmUsersTableOptions = {
    "processing": true,
    "serverSide": true,
    "bDestroy": true,
    "bAutoWidth": false,
    "lengthMenu": [ 10, 20, 50, 100 ],
    "pageLength": 100,
    "ajax": {
        "url": "/",
        "type": "POST",
        "data": function ( d ) {
            d.class = "ssm_extensions";
            d.method = "load_ssm_extensions";
            d.mode = "get";
        }
    },
    "columns": [
        { "data": "extension", "name": "extension", "orderable": true},
        { "data": "extension_name", "name" : "extension_name", "orderable": true},
        { "data": "email", "name" : "email", "orderable": true},
        { "data": "type", "name" : "type", "orderable": true},
        { "data": "did", "name" : "did", "orderable": true},
        { "data": "phone", "name" : "phone", "orderable": true},
        { "data": "permission", "name" : "permission", "orderable": true},
        { "data": "voicemail", "name" : "voicemail", "orderable": true},
        { "data": "vm_email", "name" : "vm_email", "orderable": true},
        { "data": "actions", "name" : "actions", "orderable": false},
    ],
    order: [[0, 'asc']],
    "fnDrawCallback": function (oSettings, json) {
        isEditing = false;
        updateDropdownOptionsLimits(typeSelector, masterListOfTypes);
        updateDropdownOptions(didSelector, masterListOfDids);
        updateDropdownOptions(phoneSelector, masterListOfPhones);
    }
};

(function () {
    // Hide search bar
    $("#global-search-container").hide();
    // Hide tabs' headers
    $("div.module-header").hide();

    // Open side menu automatically (if SSM user)
    if (isSsmUser) {
        var easyConfMenu = $(`a[href="#pbxMenu${menuId}"]`);
        if (easyConfMenu.length) {
            easyConfMenu.click();
        }
        var sub_menu = $(`#pbxMenu${menuId}`).children().children().children("a");
        var sub_sub_menu = $(`#pbxMenu${menuId}`).children().children().children("ul");
        if (sub_sub_menu.css("display") == "none") {
            sub_menu.click();
        }
        $("#aside-navigation").hide();
    }

    Ombutel.find("#ssm_extensions_table").DataTable(ssmUsersTableOptions);

    // Event listener for when a Type dropdown changes
    Ombutel.on('change', typeSelector, function() {
        updateDropdownOptionsLimits(typeSelector, masterListOfTypes);
    })

    // Event listener for when a DID dropdown changes
    Ombutel.on('change', didSelector, function() {
        updateDropdownOptions(didSelector, masterListOfDids);
    })

    // Event listener for when a Phone dropdown changes
    Ombutel.on('change', phoneSelector, function() {
        updateDropdownOptions(phoneSelector, masterListOfPhones);
    })

    // Event listener for when a row is clicked (start editing it)
    Ombutel.on('click', `#ssm_extensions_table tbody tr`, function() {
        $row_index = ($(this).index() + 1);
        if (isEditing && $row_index != selectedRow) {
            selectedRow = $row_index;
            save();
        } else {
            toggle_edit_row($row_index);
        }
    })
})();

function updateDropdownOptionsLimits(selector, optionsLimits) {
    var selectedValues = {};
    // Count the selected types
    $(selector).each(function() {
        var selectedValue = $(this).val();
        if (selectedValue && optionsLimits.hasOwnProperty(selectedValue)) {
            if (!selectedValues[selectedValue]) {
                selectedValues[selectedValue] = 0;
            }
            selectedValues[selectedValue]++;
        }
    });

    // Update license status
    Object.keys(optionsLimits).forEach(function(key) {
        var selectedValue = selectedValues[key] || 0;
        $('#' + key).val(selectedValue + " / " + optionsLimits[key]);
    })

    // Update each dropdown
    $(selector).each(function() {
        var $dropdown = $(this);
        var currentVal = $dropdown.val();

        // Clear the dropdown
        $dropdown.empty();
        $dropdown.append($('<option>', { value: '', text: '' }));

        // Add options based on the masterTypeLimits and selectedTypes
        for (var type in optionsLimits) {
            var countSelected = selectedValues[type] || 0;
            if (countSelected < optionsLimits[type] || type === currentVal) {
                $dropdown.append($('<option>', {
                    value: type,
                    text: licenseNameToLabel[type],
                    selected: type === currentVal
                }));
            }
        }
    });
}

function updateDropdownOptions(selector, options) {
    var selectedValues = [];
    $(selector).each(function() {
        var currSelectedValue = $(this).val();
        if (currSelectedValue) {
            selectedValues.push(currSelectedValue);
        }
    });

    $(selector).each(function() {
        var $dropdown = $(this);
        var currentVal = $dropdown.val();
        var availableValues = options.filter(function(option) {
            var value = Object.keys(option)[0];
            return !selectedValues.includes(value) || value === currentVal;
        });

        // Clear the dropdown and repopulate
        $dropdown.empty();

        // Add a blank option if needed
        $dropdown.append($('<option>', { value: '', text: ''}));

        availableValues.forEach(function(option) {
            var value = Object.keys(option)[0];
            var label = option[value];
            $dropdown.append($('<option>', {
                value: value,
                text: label,
                selected: value === currentVal
            }));
        });
    });
}

function toggle_checkbox(object){
	if(object.is(':checked')) {
		object.removeClass('option-off');
		object.addClass('option-on');
	} else {
		object.addClass('option-off');
		object.removeClass('option-on');
	}
}

function toggle_edit_row(rowIndex, force_toggle = false) {
    if (!isEditing || force_toggle) {
        var row_count = $("#ssm_extensions_table tbody tr").length;
        for (let i=1; i<=row_count; i++) {
            var rowContainer = document.querySelector(`#ssm_extensions_table tbody tr:nth-child(${i})`);

            if (!rowContainer) {
                console.error('Row container not found');
                return;
            }

            if (i == rowIndex) {
                // Text input fields
                var inputs = rowContainer.querySelectorAll('input[type="text"], input[type="hidden"]');
                var row_enabled = inputs[0].disabled; // Store the state of the first input (before toggling)
                inputs.forEach(function(input) {
                    input.disabled = !input.disabled;
                });

                // Dropdowns
                var selects = rowContainer.querySelectorAll('select');
                selects.forEach(function(select) {
                    select.disabled = !select.disabled;
                });

                // Checkboxes
                var checkboxes = rowContainer.querySelectorAll('input[type="checkbox"]');
                checkboxes.forEach(function(checkbox) {
                    checkbox.disabled = !checkbox.disabled;
                });

                // Actions
                var actions = rowContainer.querySelectorAll('a');
                actions.forEach(function(action) {
                    action.hidden = !action.hidden;
                });

                if (row_enabled) {
                    rowContainer.classList.add('ssm-selected');
                    selectedRow = rowIndex;
                } else {
                    rowContainer.classList.remove('ssm-selected');
                }
            } else {
                // Disable edit buttons for other rows (only one row can be edited at a time)
                var actions = rowContainer.querySelectorAll('a');
                actions[0].classList.remove('ssm-disabled');
                if (!isEditing) {
                    actions[0].classList.add('ssm-disabled');
                }
            }
        }

        isEditing = !isEditing;
    }

    if (!isEditing) {
        rowSelected = 0;
    }
}

function cancel_row(rowIndex) {
    toggle_edit_row(rowIndex, true);
    // Reload table
    Ombutel.find("#ssm_extensions_table").DataTable(ssmUsersTableOptions);
}

function clear_row(rowIndex) {
    var rowContainer = document.querySelector(`#ssm_extensions_table tbody tr:nth-child(${rowIndex})`);

    if (!rowContainer) {
        console.error('Row container not found');
        return;
    }

    // Clear input text fields
    var inputs = rowContainer.querySelectorAll('input[type="text"]');
    inputs.forEach(function(input) {
        input.value = '';
    });

    // Reset dropdowns to their first option (should be empty string)
    var selects = rowContainer.querySelectorAll('select');
    selects.forEach(function(select) {
        select.selectedIndex = 0;
    });

    // Uncheck checkboxes
    var checkboxes = rowContainer.querySelectorAll('input[type="checkbox"]');
    checkboxes.forEach(function(checkbox) {
        checkbox.checked = false;
    });
}

function save() {
    var ssm_apply_config = $("#ssm_apply_config");
    ssm_apply_config.val(0);
    // Submit form (only sends the editable extension)
    $("#ssm_extensions_form").submit();
    ssm_apply_config.val(1);
}
