use `ombutel`;

-- Add SSM role
insert ignore into `ombu_roles` (`owner_id`, `role`, `superadmin`, `default`, `ssm`)
    select `role_id`, 'EasyConf Admin', 'no', 'yes', 'yes'
    from `ombu_roles`
    where `ombu_roles`.`superadmin` = 'yes';
set @ssm_role_id = last_insert_id();

-- add SSM role privileges to core / ombutel / endpoint / tenants / search / reset_password
insert ignore into `ombu_role_privileges` (`role_id`, `module_id`, `allow_view`, `allow_add`, `allow_edit`, `allow_delete`)
    select @ssm_role_id, `module_id`, 'yes', 'yes', 'yes', 'yes'
    from `ombu_modules`
    where `ombu_modules`.`name` in ('core', 'search', 'reset_password');

-- Add SSM menu
insert ignore into `ombu_menu` (`label`, `parent_id`, `module_id`, `icon`, `sort`)
    values ('menu.ssm', null, null, 'fa fa-wrench fa-fw', 6);
set @ssm_menu_id = last_insert_id();

-- Add SSM sub-menu (config)
insert ignore into `ombu_menu` (`label`, `parent_id`, `module_id`, `sort`)
    values ('menu.ssm_config', @ssm_menu_id, null, 1);
set @config_menu_id = last_insert_id();

-- Add 'ssm system details' module / action / role_privileges
insert ignore into `ombu_modules` (`name`, `has_dialplan`, `admin`, `version`, `portal`)
    values ("ssm_system_details", "no", "no", "1.0", "no");
set @ssm_sysd_module = last_insert_id();

insert ignore into `ombu_actions` (`name`, `displayname`, `function`)
    values ('ssm-system-details', 'menu.ssm_system_details', 'modules\\ssm_system_details\\ssm_system_details::open');

insert ignore into `ombu_role_privileges` (`role_id`, `module_id`, `allow_view`, `allow_add`, `allow_edit`, `allow_delete`)
    select `role_id`, @ssm_sysd_module, 'yes', 'yes', 'yes', 'yes'
        from `ombu_roles`
        where `superadmin` = 'yes' or `role_id` = @ssm_role_id;

-- Add 'ssm_extension_type' table
create table `ombu_ssm_extensions_type` (
    `extension_id` int(10) unsigned not null,
    `type` varchar(255),
    foreign key (`extension_id`) references `ombu_extensions`(`extension_id`) on delete cascade
);

-- Add 'ssm extensions' module / action / role_privileges / menu
insert ignore into `ombu_modules` (`name`, `has_dialplan`, `admin`, `version`, `portal`)
    values ("ssm_extensions", "no", "no", "1.0", "no");
set @ssm_extensions_module = last_insert_id();

insert ignore into `ombu_actions` (`name`, `displayname`, `function`)
    values ('ssm-extensions', 'menu.ssm_extensions', 'modules\\ssm_extensions\\ssm_extensions::open');

insert ignore into `ombu_role_privileges` (`role_id`, `module_id`, `allow_view`, `allow_add`, `allow_edit`, `allow_delete`)
    select `role_id`, @ssm_extensions_module, 'yes', 'yes', 'yes', 'yes'
        from `ombu_roles`
        where `superadmin` = 'yes' or `role_id` = @ssm_role_id;

insert ignore into `ombu_menu` (`label`, `parent_id`, `module_id`, `sort`, `action`)
    values ('menu.ssm_extensions', @config_menu_id, @ssm_extensions_module, 1, "ssm-extensions");
